#ifdef DEBUG

#include <stdarg.h>

#include "debug.h"
#include "proto.h"

#define DBG_BUFFER_SIZE 8192

static int dbg_buffer_filled;

static char dbg_buffer[DBG_BUFFER_SIZE];

void debug_putc(char c)
{
  extern void *fb_addr;
  if(fb_addr) {
    if(dbg_buffer_filled) {
      int i;
      for(i=0; i<dbg_buffer_filled; i++)
	fb_putc(dbg_buffer[i]);
      dbg_buffer_filled = 0;
    }
    fb_putc(c);
  } else if(dbg_buffer_filled < DBG_BUFFER_SIZE)
    dbg_buffer[dbg_buffer_filled++] = c;
}

void debug_puts(const char *s)
{
  while(*s)
    debug_putc(*s++);
}

static void debug_putn(long n, int base)
{
  long r;
  if(base == 10 && n < 0) {
    n = -n;
    debug_putc('-');
  }
  r = ((unsigned long)n)/base;
  n = ((unsigned long)n)%base;
  if(r)
    debug_putn(r, base);
  debug_putc("0123456789ABCDEF"[n]);
}

#if 1
void debug_vprintf(const char *fmt, va_list ap)
{
  char c;
  while((c = *fmt++))
    if(c == '%')
      switch((c = *fmt++)) {
      case 0:
	--fmt;
	break;
      case 's':
	debug_puts(va_arg(ap, const char *));
	break;
      case 'p':
	debug_putn((unsigned long)va_arg(ap, void *), 16);
	break;
      case 'd':
	debug_putn(va_arg(ap, int), 10);
	break;
      case '0':
	if(fmt[0] == '8' && fmt[1] == 'x')
	  fmt += 2;
	else {
	  debug_putc(c);
	  break;
	}
      case 'x':
	debug_putn(va_arg(ap, unsigned int), 16);
	break;
      case 'l':
	switch((c = *fmt++)) {
	case 'd':
	  debug_putn(va_arg(ap, long), 10);
	  break;
	case 'x':
	  debug_putn(va_arg(ap, unsigned long), 16);
	  break;
	default:
	  --fmt;
	  debug_putc('l');
	  if(c)
	    debug_putc(c);
	  break;
	}
	break;
      default:
	debug_putc(c);
	break;
      } else
      debug_putc(c);
}
#else
void debug_vprintf(const char *fmt, va_list ap)
{
#if 0
  char *s = 0;
  int i, l = vasprintf(&s, fmt, ap);
  for(i=0; i<l; i++)
    debug_putc(s[i]);
  free(s);
#else
  char buf[512];
  int i, l = snprintf(buf, sizeof(buf), fmt, ap);
  for(i=0; i<l; i++)
    debug_putc(buf[i]);  
#endif
}
#endif

void debug_printf(const char *fmt, ...)
{
  va_list ap;
  va_start(ap, fmt);
  debug_vprintf(fmt, ap);
  va_end(ap);
}

#endif
