#include "debug.h"
#include "proto.h"

void exception_handler(unsigned long vector, unsigned long saved_pc,
		       unsigned long saved_msr)
{
  DBG("EXCEPTION VECTOR %lx at %lx (MSR=%lx)\n",
      vector, saved_pc, saved_msr);
#ifdef DEBUG
  sleep(60);
#endif
  lv1_panic(0);
}

void main()
{
  int action = -1;
  DBG("ENTRY\n");
  time_init();
  av_init();
  fb_init();
  dev_init();

  if(read_config()<0) {
    fb_printf("No config file could be loaded.\n");
    fb_printf("Press RETURN to go back to Game OS.\n\n");
    while(usb_kbd_getc() != 0xd)
      ;
  } else {
    action = menu();
  }

  if(action < 0) {
    fb_printf("Returning to Game OS...\n");
    set_boot_flag(0);
  } else
    fb_printf("Starting image\n");

  dev_term();
  fb_term();
  av_term();
  mmu_term();
  if(action < 1)
    reboot();
  else
    execute();
}
