
/* mmu.c */
extern void mmu_init(void);
extern void mmu_term(void);
extern void *ioremap(unsigned long paddr, unsigned long size);

/* time.c */
extern unsigned long tb_hz;
extern unsigned long read_tb(void);
extern void tbsleep(unsigned long cnt);
extern void sleep(unsigned long cnt);
extern void usleep(unsigned long cnt);
extern void time_init(void);

/* vuart.c */
extern long vuart_write(unsigned long unit, const unsigned char *data,
			unsigned long length);
extern long vuart_read(unsigned long unit, unsigned char *data,
		       unsigned long length, unsigned long timeout);
extern int vuart_init(unsigned long unit);

/* sysmgr.c */
extern void reboot(void);

/* av.c */
extern int av_width, av_height, av_pitch, av_fps;
extern void av_init(void);

/* flash.c */
extern struct driver flash_driver;
extern int set_boot_flag(int boot_flag);

/* fb.c */
extern void *fb_addr;
extern void draw_glyph_8x8(int px, int py, const unsigned char *g,
			   unsigned int fg, unsigned int bg);
extern void fb_putc(char c);
extern void fb_puts(const char *s);
extern void fb_printf(const char *fmt, ...);
extern void fb_gotoxy(int x, int y);
extern void fb_setcolor(unsigned int fg, unsigned int bg);
extern void fb_clear(unsigned int colour);
extern void fb_flip(unsigned long offset);
extern void fb_init(void);
extern void fb_term(void);

/* font_8x8.c */
extern const unsigned char font8x8[];

/* dev.c */
struct dev {
  unsigned long bus_id, device_id;
  unsigned long bus_index, dev_index, flags;
  unsigned long mmio_lpar, dma_offset;
  void *regs;
};
struct driver {
  int (*driver_init)(struct dev *);
  int (*driver_term)(struct dev *);
};
extern void dev_init(void);
extern void dev_term(void);

/* usb.c */
struct usb_device;
struct devrequest;
extern int usb_init(void); /* initialize the USB Controller */
extern int usb_stop(void); /* stop the USB Controller */
extern int usb_set_protocol(struct usb_device *dev, int ifnum, int protocol);
extern int usb_set_idle(struct usb_device *dev, int ifnum, int duration, int report_id);
extern struct usb_device * usb_get_dev_index(int index);
extern int usb_control_msg(struct usb_device *dev, unsigned int pipe,
			   unsigned char request, unsigned char requesttype,
			   unsigned short value, unsigned short index,
			   void *data, unsigned short size, int timeout);
extern int usb_bulk_msg(struct usb_device *dev, unsigned int pipe,
			void *data, int len, int *actual_length, int timeout);
extern int usb_submit_int_msg(struct usb_device *dev, unsigned long pipe,
			      void *buffer,int transfer_len, int interval);
extern void usb_disable_asynch(int disable);
extern int usb_maxpacket(struct usb_device *dev,unsigned long pipe);
extern int usb_get_configuration_no(struct usb_device *dev,unsigned char *buffer,int cfgno);
extern int usb_get_report(struct usb_device *dev, int ifnum, unsigned char type, unsigned char id, void *buf, int size);
extern int usb_get_class_descriptor(struct usb_device *dev, int ifnum,
				    unsigned char type, unsigned char id, void *buf, int size);
extern int usb_clear_halt(struct usb_device *dev, int pipe);
extern int usb_string(struct usb_device *dev, int index, char *buf, unsigned long size);
extern int usb_set_interface(struct usb_device *dev, int interface, int alternate);

/* usb_kbd.c */
extern int drv_usb_kbd_init(void);
extern int usb_kbd_testc(void);
extern int usb_kbd_getc(void);

/* usb_ohci.c */
extern struct driver usb_ohci_driver;
extern int usb_lowlevel_init(void);
extern int usb_lowlevel_stop(void);
extern void usb_lowlevel_poll(void);
extern int submit_bulk_msg(struct usb_device *dev, unsigned long pipe, void *buffer,int transfer_len);
extern int submit_control_msg(struct usb_device *dev, unsigned long pipe, void *buffer,
			      int transfer_len,struct devrequest *setup);
extern int submit_int_msg(struct usb_device *dev, unsigned long pipe, void *buffer,
			  int transfer_len, int interval);

/* hdd.c */
extern struct driver hdd_driver;
extern int hdd_read_partition(int partition, unsigned long sector,
			      unsigned int offset, unsigned long length,
			      char *buf);
extern int hdd_get_root_partition(void);
extern int hdd_get_dos_partition(int n);

/* ext2.c */
struct ext2_data;
struct file {
  unsigned long size, offset;
  struct ext2_data *data;
};
extern int ext2_open (struct file *file, int partition, const char *name);
extern long ext2_read (struct file *file, char *buf, unsigned long len);
extern int ext2_close (struct file *file);
extern int ext2_label (int partition, char **label);

/* config.c */
extern int read_config();
extern void query_labels(int *p_num, int *p_def);
extern void query_timeout(int *p_timeout);
extern const char *get_label_key(int n);
extern const char *get_label_value(int n);

/* menu.c */
extern int menu();

/* loader.c */
extern int load_object(const char *cmdline);

/* exec.S */
extern int prepare_execute(int type, char *image, unsigned long imgsize,
			   char *initrd, unsigned long initrdsize,
			   const char *cmdline, void *scratchpad);
extern void execute(void);

/* debug.c */
#ifdef DEBUG
extern void debug_putc(char c);
extern void debug_puts(const char *s);
extern void debug_printf(const char *fmt, ...)
  __attribute__((format(printf,1,2)));
#endif

/* hv.S */
#include "lv1callarg.h"
#define LV1_CALL(name, in, out, num) \
	extern long lv1_##name(LV1_##in##_IN_##out##_OUT_ARG_DECL);
#include "lv1calltab.h"
#undef LV1_CALL

