#include "debug.h"
#include "proto.h"

long vuart_write(unsigned long unit, const unsigned char *data,
		 unsigned long length)
{
  long status;
  unsigned long actual;
  DBG("lv1_write_virtual_uart(%ld, %p, %ld, %p)", unit, data, length, &actual);
  status = lv1_write_virtual_uart(unit, (unsigned long)data, length, &actual);
  DBG("=> %ld (%ld)\n", status, actual);
  if(status)
    return -1;
  else
    return actual;
}

long vuart_read(unsigned long unit, unsigned char *data,
		unsigned long length, unsigned long timeout)
{
  long status;
  unsigned long actual, total=0;
  DBG("lv1_read_virtual_uart(%ld, %p, %ld, %p)", unit, data, length, &actual);
  for(;;) {
    status = lv1_read_virtual_uart(unit, (unsigned long)data, length, &actual);
    if(status)
      return -1;
    total += actual;
    if(actual >= length)
      break;
    data += actual;
    length -= actual;
    if(!timeout) {
      DBG(" TIMEOUT ");
      break;
    } else if(timeout > 5000) {
      usleep(5000);
      timeout -= 5000;
    } else {
      usleep(timeout);
      timeout = 0;
    }
  }
  DBG("=> (%ld)\n", total);
  return total;
}

int vuart_init(unsigned long unit)
{
  unsigned long status;
  unsigned long value;

  DBG("lv1_get_virtual_uart_param(%ld, 0, %p)", unit, &value);
  status = lv1_get_virtual_uart_param(unit, 0, &value);
  DBG("=> %ld (%ld)\n", status, value);
  if(status)
    return -1;
  else
    return 0;
}
